/**
 * CSelect
 * @author Tevin
 */

<template>
    <view class="c-select">
        <picker
            v-if="!selectByPage"
            mode="selector"
            :range="options"
            :value="current"
            range-key="name"
            @change="evt=>handleChange(evt.detail)"
        >
            <AtInput
                ref="input"
                :name="itemRes.name"
                :title="itemRes.label"
                :required="itemRes.required"
                :error="itemRes.error"
                :placeholder="placeholder"
                :value="selected"
            >
                <view class="at-icon at-icon-chevron-right" />
            </AtInput>
        </picker>
        <view v-else-if="selectByPage.length > 5">
            <AtInput
                :name="itemRes.name"
                :title="itemRes.label"
                :required="itemRes.required"
                :error="itemRes.error"
                :placeholder="placeholder"
                :value="selected"
                :onFocus="evt=>onGoToSelectorPage()"
            >
                <view class="at-icon at-icon-chevron-right" />
            </AtInput>
        </view>
    </view>
</template>

<script>
import Taro from '@tarojs/taro';
import { AtInput } from 'taro-ui-vue';
import './cSelect.scss';

export default {
    name: 'CSelect',
    components: {
        AtInput,
    },
    props: {
        options: Array,
        placeholder: String,
        itemRes: Object,
        selectByPage: String,
        onSelectFromPage: Function,
    },
    data() {
        return {};
    },
    computed: {
        optionKey() {
            return typeof (this.options[0] || {}).value === 'undefined' ? 'id' : 'value';
        },
        current() {
            const curVal = this.itemRes.formData[this.itemRes.name];
            for (let i = 0, item; (item = this.options[i]); i++) {
                if (curVal === item[this.optionKey]) {
                    return i;
                }
            }
            return -1;
        },
        selected() {
            const curVal = this.itemRes.formData[this.itemRes.name];
            for (let i = 0, item; (item = this.options[i]); i++) {
                if (curVal === item[this.optionKey]) {
                    return item.name;
                }
            }
            return '';
        },
    },
    methods: {
        handleChange(evt) {
            const item = this.options[evt.value];
            this.itemRes.onChange(item[this.optionKey]);
        },
        onGoToSelectorPage() {
            Taro.navigateTo({
                url: this.selectByPage,
                events: {
                    'CSelect:onSelected': data => {
                        this.onSelectFromPage(data);
                    },
                },
            });
        },
    },
    mounted() {},
};
</script>